function kdispbrberg(ref,ksp)

%KDISPBRBERG   Display the path of Khepera during Braitenberg mode
%
%kdispbrberg(ref)
%  Display the path of Khepera (ctrl-c to stop).
%  Use the reference obtained with kopen.
%
%kdispbrberg(ref,speed)
%  Use a speed factor, < 1 to go slower

% Written by Yves Piguet, 8/98.

gain = [-5,-15,-18,6,4,4,3,5;4,4,6,-18,-15,-5,5,3] / 400;
offset = 20 * [1;1];

if nargin >= 2
	gain = gain * ksp;
	offset = offset * ksp;
end

width = 54;		% width between wheels [mm]
wn = 1 / 12;	% mm/incr

pos0 = kwheelpos(ref);
phi = 0;

x = 0;
y = 0;

eval('set(gcf, ''doublebuffer'', ''on'')','');
	% unsupported feature of Matlab 5.2 to suppress flashing
	% eval is used to avoid fatal errors with previous versions

while 1
	sensors = kproxsens(ref);			% read the proximity sensors
	speed = gain * sensors + offset;	% calculate the speed
	kspeed(ref,speed(1),speed(2));		% write the speed
	pos = kwheelpos(ref) * wn;
	dphi = (pos - pos0)' * [1;-1] / width;
	l = (pos - pos0)' * [1; 1] / 2;
	x = [x, x(end)+cos(phi + dphi / 2)*l];
	y = [y, y(end)+sin(phi + dphi / 2)*l];
	phi = phi + dphi;
	plot(x, y);
	drawnow;
end
