function KproximityG(ref, style, action)
%KPROXIMITYG   Display the value of the proximity sensors of Khepera
%
%kProximityG(ref)
%  Display the value of the proximity sensors as an histogram
%   Use the "Start" and "Stop" buttons to control 
%   the animation.                                
%  Use the communication parameters specified with kcmd.
%
%kProximityG(ref,style)
%  Display as an histogram (style = 'hist') or a polar plot (polar).

% Written by Yves Piguet, 8/98.
%            Skye Legon, 2/99.
%   Adapted from Demo by Ned Gulley, 6-21-93; jae Roh, 10-15-96
%   Copyright (c) 1984-96 by The MathWorks, Inc.
%   $Revision: 5.7 $  $Date: 1996/10/16 21:47:48 $

% Possible actions:
% initialize
% close

% Information regarding the play status will be held in
% the Userdata of the start button handle (which is stored in 
% the figure Userdata) according to the following table:
% (can't use axis Userdata as it gets clobbered by the bar command)
play= 1;
stop=-1;

maxValue = 1024;		% maximum value of a sensor

refstring = sprintf('[%f %f %f %f]',ref);
   
if nargin < 2
	style = 'hist';
end

if nargin < 3,
    action='initialize';
end;

if strcmp(action,'initialize'),
    oldFigNumber=watchon;

    figNumber=figure( ...
        'Name','Khepera Proximity Sensors (c) K-Team SA 1999', ...
        'NumberTitle','off', ...
        'Visible','off');
    colordef(figNumber,'black')
    axes( ...
        'Units','normalized', ...
        'Position',[0.07 0.10 0.75 0.85], ...
        'Visible','off');

    text(0,0,'Press the "Start" button to begin', ...
        'HorizontalAlignment','center');
    axis([-1 1 -1 1]);
     
    eval('set(gcf, ''doublebuffer'', ''on'')','');
	 % unsupported feature of Matlab 5.2 to suppress flashing
	 % eval is used to avoid fatal errors with previous versions
   
    %===================================
    % Information for all buttons
    labelColor=[0.8 0.8 0.8];
    yInitPos=0.90;
    xPos=0.85;
    btnLen=0.10;
    btnWid=0.10;
    % Spacing between the button and the next command's label
    spacing=0.05;

    %====================================
    % The CONSOLE frame
    frmBorder=0.02;
    yPos=0.05-frmBorder;
    frmPos=[xPos-frmBorder yPos btnLen+2*frmBorder 0.9+2*frmBorder];
    h=uicontrol( ...
        'Style','frame', ...
        'Units','normalized', ...
        'Position',frmPos, ...
        'BackgroundColor',[0.50 0.50 0.50]);
    
    %====================================
    % The START button
    btnNumber=1;
    yPos=0.90-(btnNumber-1)*(btnWid+spacing);
    labelStr='Start';
    cmdStr='start';
    callbackStr=['kProximityG(' refstring ',''' style ''',''start'');'];

    % Generic button information
    btnPos=[xPos yPos-spacing btnLen btnWid];
    startHndl=uicontrol( ...
        'Style','pushbutton', ...
        'Units','normalized', ...
        'Position',btnPos, ...
        'String',labelStr, ...
        'Interruptible','on', ...
        'Userdata',stop, ...
        'Callback',callbackStr);

    %====================================
    % The STOP button
    btnNumber=2;
    yPos=0.90-(btnNumber-1)*(btnWid+spacing);
    labelStr='Stop';
    % Setting userdata to -1 (=stop) will stop the demo.
    %callbackStr='set(gca,''Userdata'',-1)';
    callbackStr='eval(''v=get(gcf,''''Userdata'''');set(v(1),''''Userdata'''',-1);'')';
    
    % Generic  button information
    btnPos=[xPos yPos-spacing btnLen btnWid];
    stopHndl=uicontrol( ...
        'Style','pushbutton', ...
        'Units','normalized', ...
        'Position',btnPos, ...
        'Enable','off', ...
        'String',labelStr, ...
        'Callback',callbackStr);
     
    %====================================
    % The INFO button
    labelStr='Info';
    callbackStr=['kProximityG(' refstring ',''' style ''',''info'');'];
    infoHndl=uicontrol( ...
        'Style','push', ...
        'Units','normalized', ...
        'position',[xPos 0.20 btnLen 0.10], ...
        'string',labelStr, ...
        'call',callbackStr);

    %====================================
    % The CLOSE button
    labelStr='Close';
    callbackStr='close(gcf)';
    closeHndl=uicontrol( ...
        'Style','push', ...
        'Units','normalized', ...
        'position',[xPos 0.05 btnLen 0.10], ...
        'string',labelStr, ...
        'call',callbackStr);
     
    % Uncover the figure
    hndlList=[startHndl stopHndl infoHndl closeHndl];
    set(figNumber,'Visible','on', ...
        'UserData',hndlList);

    watchoff(oldFigNumber);
    figure(figNumber);

elseif strcmp(action,'start'),
    figNumber=gcf;
    hndlList=get(figNumber,'UserData');
    startHndl=hndlList(1);
    stopHndl=hndlList(2);
    infoHndl=hndlList(3);
    closeHndl=hndlList(4);
    set(startHndl,'Userdata',play);
    set([startHndl closeHndl infoHndl],'Enable','off');
    set(stopHndl,'Enable','on');
    set(figNumber,'Backingstore','off');
        
    % ====== Start of Demo
    
    sensorOrder = [8,1:7];	% back left sensor displayed first
    sensorAngles = pi / 180 * [180,135,100,80,45,0,260,280];

    % The main loop
    
    switch style
    case 'hist'
       
       while (get(startHndl,'Userdata')==play)
          sensors = kProximity(ref);
          bar(sensors(sensorOrder));
          axis([0.5,8.5,0,maxValue]);
          drawnow;
       end
    case 'polar'
       while (get(startHndl,'Userdata')==play)
         sensors = kProximity(ref) + 50;
         polar1(sensorAngles(sensorOrder), sensors(sensorOrder)', maxValue);
         drawnow
       end
    end;    % Main loop ...
    
    % ====== End of Demo
    set([startHndl closeHndl infoHndl],'Enable','on');
    set(stopHndl,'Enable','off');
    
 elseif strcmp(action,'info')
    helptext = strvcat( ...
       'Program for graphical display of Khepera proximity sensors.',...
       ' ',...
       'Authors: Yves Piguet, 8/98',...
       '         Skye Legon, 2/99',...
       ' ',...
       'Copyright 1999 K-Team SA');
    helpwin(helptext,'Khepera Information');
    
end;    % if strcmp(action, ...